import { parseArgs } from "node:util";
import { titleCase } from "title-case";
import { withSpinner } from "../cli/spinners.js";
import { allArgOptions } from "./args.js";
import { augmentOptionsWithExcludes } from "./augmentOptionsWithExcludes.js";
import { ensureRepositoryExists } from "./ensureRepositoryExists.js";
import { getGitHub } from "./getGitHub.js";
import { getPrefillOrPromptedOption } from "./getPrefillOrPromptedOption.js";
import { getGitAndNpmDefaults } from "./readGitAndNpmDefaults/index.js";
async function readOptions(args) {
  const defaults = getGitAndNpmDefaults();
  const { values } = parseArgs({
    args,
    options: allArgOptions,
    strict: false,
    tokens: true
  });
  const options = {
    author: values.author,
    base: values.base,
    createRepository: values["create-repository"],
    description: values.description,
    email: values.email,
    excludeCompliance: values["exclude-compliance"],
    excludeContributors: values["exclude-contributors"],
    excludeLintJson: values["exclude-lint-json"],
    excludeLintKnip: values["exclude-lint-knip"],
    excludeLintMd: values["exclude-lint-md"],
    excludeLintPackageJson: values["exclude-lint-package-json"],
    excludeLintPackages: values["exclude-lint-packages"],
    excludeLintPerfectionist: values["exclude-lint-perfectionist"],
    excludeLintSpelling: values["exclude-lint-spelling"],
    excludeLintYml: values["exclude-lint-yml"],
    excludeReleases: values["exclude-releases"],
    excludeRenovate: values["exclude-renovate"],
    excludeTests: values["unit-tests"],
    funding: values.funding,
    owner: values.owner,
    repository: values.repository,
    skipGitHubApi: !!values["skip-github-api"],
    skipInstall: !!values["skip-install"],
    skipRemoval: !!values["skip-removal"],
    skipRestore: values["skip-restore"],
    skipUninstall: !!values["skip-uninstall"],
    title: values.title
  };
  options.owner ??= await getPrefillOrPromptedOption(
    values.owner,
    "What organization or user will the repository be under?",
    defaults.owner
  );
  if (!options.owner) {
    return {
      cancelled: true,
      options
    };
  }
  options.repository ??= await getPrefillOrPromptedOption(
    options.repository,
    "What will the kebab-case name of the repository be?",
    defaults.repository
  );
  if (!options.repository) {
    return {
      cancelled: true,
      options
    };
  }
  const { github, repository } = await ensureRepositoryExists(
    values["skip-github-api"] ? void 0 : await withSpinner("Checking GitHub authentication", getGitHub),
    {
      createRepository: options.createRepository,
      owner: options.owner,
      repository: options.repository
    }
  );
  if (!repository) {
    return { cancelled: true, options };
  }
  options.description ??= await getPrefillOrPromptedOption(
    options.description,
    "How would you describe the new package?",
    async () => await defaults.description() ?? "A very lovely package. Hooray!"
  );
  if (!options.description) {
    return { cancelled: true, options };
  }
  options.title ??= await getPrefillOrPromptedOption(
    options.title,
    "What will the Title Case title of the repository be?",
    async () => await defaults.title() ?? titleCase(repository).replaceAll("-", " ")
  );
  if (!options.title) {
    return { cancelled: true, options };
  }
  const augmentedOptions = await augmentOptionsWithExcludes({
    ...options,
    author: options.author ?? await defaults.owner(),
    email: options.email ?? await defaults.email(),
    funding: options.funding ?? await defaults.funding(),
    repository
  });
  if (!augmentedOptions) {
    return {
      cancelled: true,
      options
    };
  }
  return {
    cancelled: false,
    github,
    options: augmentedOptions
  };
}
export {
  readOptions
};
//# sourceMappingURL=readOptions.js.map